@@ -19,7 +19,7 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: totemComplexPlugin.cpp 5065 2008-02-04 14:32:50Z hadess $
+ * $Id: totemComplexPlugin.cpp 5132 2008-02-15 23:52:58Z hadess $
  */
 
 #include <mozilla-config.h>
@@ -68,7 +68,6 @@ totemScriptablePlugin::operator new (size_t aSize) CPP_THROW_NEW
 
 totemScriptablePlugin::totemScriptablePlugin (totemPlugin *aPlugin)
   : mPlugin(aPlugin),
-    mVolume(50),
     mPlayState(eState_Stopped)
 {
   D ("%s ctor [%p]", kClassDescription, (void*) this);
@@ -2019,7 +2018,7 @@ totemScriptablePlugin::SetVolume (PRInt32 volume)
   nsresult rv = mPlugin->SetVolume ((double) volume / 100);
 
   /* Volume passed in is 0 through to 100 */
-  mVolume = volume;
+  mPlugin->mVolume = volume;
 
   return NS_OK;
 }
@@ -2030,7 +2029,7 @@ totemScriptablePlugin::GetVolume(PRInt32 *_retval)
 {
   TOTEM_SCRIPTABLE_LOG_ACCESS ();
   
-  *_retval = mVolume;
+  *_retval = mPlugin->mVolume;
   return NS_OK;
 }
 
