@@ -254,12 +254,12 @@ totem_action_exit (Totem *totem)
 	if (totem->gc)
 		g_object_unref (G_OBJECT (totem->gc));
 
-	if (totem->win)
-		gtk_widget_destroy (GTK_WIDGET (totem->win));
-
 	if (totem->fs)
 		g_object_unref (totem->fs);
 
+	if (totem->win)
+		gtk_widget_destroy (GTK_WIDGET (totem->win));
+
 	g_object_unref (totem);
 
 	gnome_vfs_shutdown ();
@@ -667,8 +667,9 @@ window_state_event_cb (GtkWidget *window, GdkEventWindowState *event,
 		return FALSE;
 
 	if (event->new_window_state & GDK_WINDOW_STATE_FULLSCREEN) {
-		if (totem->controls_visibility != TOTEM_CONTROLS_UNDEFINED)
+		if (totem->controls_visibility != TOTEM_CONTROLS_UNDEFINED) {
 			totem_action_save_size (totem);
+		}
 		totem_fullscreen_set_fullscreen (totem->fs, TRUE);
 
 		totem->controls_visibility = TOTEM_CONTROLS_FULLSCREEN;
@@ -682,10 +683,11 @@ window_state_event_cb (GtkWidget *window, GdkEventWindowState *event,
 		action = gtk_action_group_get_action (totem->main_action_group,
 				"show-controls");
 
-		if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)))
+		if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action))) {
 			totem->controls_visibility = TOTEM_CONTROLS_VISIBLE;
-		else
+		} else {
 			totem->controls_visibility = TOTEM_CONTROLS_HIDDEN;
+		}
 
 		show_controls (totem, TRUE);
 		totem_action_set_sensitivity ("fullscreen", TRUE);
@@ -696,12 +698,6 @@ window_state_event_cb (GtkWidget *window, GdkEventWindowState *event,
 	return FALSE;
 }
 
-void
-fs_exit1_activate_cb (GtkButton *button, Totem *totem)
-{
-	totem_action_fullscreen_toggle (totem);
-}
-
 void
 totem_action_fullscreen_toggle (Totem *totem)
 {
@@ -720,6 +716,12 @@ totem_action_fullscreen (Totem *totem, gboolean state)
 	totem_action_fullscreen_toggle (totem);
 }
 
+void
+fs_exit1_activate_cb (GtkButton *button, Totem *totem)
+{
+	totem_action_fullscreen (totem, FALSE);
+}
+
 void
 totem_action_open (Totem *totem)
 {
@@ -1248,26 +1250,17 @@ static gboolean
 totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		int drop_type, gboolean empty_pl)
 {
-	GList *list, *p, *file_list;
+	char **list;
+	guint i;
+	GList *p, *file_list;
 	gboolean cleared = FALSE;
 
-	list = gnome_vfs_uri_list_parse ((const char *)data->data);
-
-	if (list == NULL)
-		return FALSE;
-
-	p = list;
+	list = g_uri_list_extract_uris ((const char *)data->data);
 	file_list = NULL;
 
-	while (p != NULL)
-	{
-		file_list = g_list_prepend (file_list, 
-				gnome_vfs_uri_to_string
-				((const GnomeVFSURI*)(p->data), 0));
-		p = p->next;
-	}
+	for (i = 0; list[i] != NULL; ++i)
+		file_list = g_list_prepend (file_list, list[i]);
 
-	gnome_vfs_uri_list_free (list);
 	if (file_list == NULL)
 		return FALSE;
 
@@ -1305,7 +1298,6 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		/* Super _NETSCAPE_URL trick */
 		if (drop_type == 1)
 		{
-			g_free (p->data);
 			p = p->next;
 			if (p != NULL) {
 				if (g_str_has_prefix (p->data, "file:") != FALSE)
@@ -1318,9 +1310,9 @@ totem_action_drop_files (Totem *totem, GtkSelectionData *data,
 		totem_playlist_add_mrl (totem->playlist, filename, title);
 
 		g_free (filename);
-		g_free (p->data);
 	}
 
+	g_strfreev (list);
 	g_list_free (file_list);
 	gdk_window_set_cursor (totem->win->window, NULL);
 
@@ -2062,8 +2054,9 @@ totem_action_remote (Totem *totem, TotemRemoteCommand cmd, const char *url)
 		break;
 	}
 
-	if (handled != FALSE &&
-			gtk_window_is_active (GTK_WINDOW (totem->win))) {
+	if (handled != FALSE
+			&& gtk_window_is_active (GTK_WINDOW (totem->win))
+			&& totem_fullscreen_is_fullscreen (totem->fs) != FALSE) {
 		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
 	}
 }
@@ -2245,7 +2238,8 @@ totem_is_seekable (Totem *totem)
 static void
 on_mouse_click_fullscreen (GtkWidget *widget, Totem *totem)
 {
-	totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
+	if (totem_fullscreen_is_fullscreen (totem->fs) != FALSE)
+		totem_fullscreen_motion_notify (NULL, NULL, totem->fs);
 }
 
 static gboolean
@@ -2974,7 +2968,6 @@ video_widget_create (Totem *totem)
 	}
 
 	totem_preferences_tvout_setup (totem);
-	totem_preferences_visuals_setup (totem);
 	totem_action_zoom (totem, ZOOM_RESET);
 
 	g_signal_connect_after (G_OBJECT (totem->bvw),
@@ -3048,6 +3041,8 @@ video_widget_create (Totem *totem)
 	gtk_widget_realize (GTK_WIDGET (totem->bvw));
 	gtk_widget_show (GTK_WIDGET (totem->bvw));
 
+	totem_preferences_visuals_setup (totem);
+
 	bacon_video_widget_set_volume (totem->bvw,
 			((double) gconf_client_get_int (totem->gc,
 				GCONF_PREFIX"/volume", NULL)) / 100.0);
@@ -3192,7 +3187,6 @@ main (int argc, char **argv)
 	gtk_range_set_adjustment (GTK_RANGE (totem->fs->seek), totem->seekadj);
 
 	totem_session_setup (totem, argv);
-	totem_setup_recent (totem);
 	totem_setup_file_monitoring (totem);
 	totem_setup_file_filters ();
 	totem_setup_play_disc (totem);
@@ -3217,16 +3211,16 @@ main (int argc, char **argv)
 	totem_fullscreen_set_video_widget (totem->fs, totem->bvw);
 
 	if (optionstate.fullscreen != FALSE) {
-		totem_action_fullscreen (totem, TRUE);
-		long_action ();
 		gtk_widget_show (totem->win);
 		gdk_flush ();
+		totem_action_fullscreen (totem, TRUE);
 	}
-	long_action ();
 
 	/* The prefs after the video widget is connected */
 	totem_setup_preferences (totem);
 
+	totem_setup_recent (totem);
+
 	/* Command-line handling */
 	totem_options_process_late (totem, &optionstate);
 
